v1.1.0
=======
- docstrings were updated with information about preserving order for agents
- :func:`rohub.resource_download` now supports redirection; a specific type of resource can be redirected as EGI notebook url
- the docstrings attached to the following functions were updated with template of how the data should be provided for non-existing agents: :func:`rohub.ros_set_authors`, :func:`rohub.ros_set_contributors`, :func:`rohub.ros_set_copyright_holders`, :func:`rohub.ros_set_publishers`, :func:`ResearchObject.set_copyright_holders`, :func:`ResearchObject.set_publishers`, :func:`ResearchObject.set_authors`, :func:`ResearchObject.ros_set_contributors`
- renaming the possible format in :func:`rohub.ros_export_to_create` from json-ld to jsonld for convenience purposes
- shared_link is now accessible as an attribute of the Resource object
- clarified doctsring in :func:`rohub.ros_add_annotations`
- direct hyperlink to the package site and to the LICENSE file fixed in README
- fixed typo in :func:`rohub.resource_delete_license`
- bugfix to optional parameter object_class not being accepted in :func:`rohub.ros_add_triple`
- results for :func:`rohub.ros_find` extended with new metadata
- bugfix in :func:`rohub.resource_update_metadata` it will no longer send a faulty request when resource type was set to empty string
- body_specification_json is from now required when using :func:`rohub.ros_add_geolocation` and :func:`ResarchObject.ros_add_geolocation`
- :func:`rohub.update_custom_license` moved to the admin module due to the change of permissions
- added functions: 
    * :func:`rohub.resource_find`
    * :func:`rohub.resource_list_keywords`
    * :func:`rohub.resource_add_keywords`
    * :func:`rohub.resource_set_keywords`
    * :func:`rohub.resource_delete_keywords`
    * :func:`Resource.list_keywords`
    * :func:`Resource.add_keywords`
    * :func:`Resource.set_keywords`
    * :func:`Resource.delete_keywords`
    * :func:`rohub.ros_aggregate_datacube`
    * :func:`ResarchObject.aggregate_datacube`
    * :func:`rohub.list_communities`
    * :func:`rohub.create_community`
    * :func:`admin.delete_community`
    * :func:`admin.update_community`
    * :func:`rohub.ros_list_communities`
    * :func:`rohub.ros_add_community`
    * :func:`rohub.ros_set_community`
    * :func:`rohub.ros_delete_communities`
    * :func:`ResearchObject.list_communities`
    * :func:`ResarchObject.add_community`
    * :func:`ResarchObject.set_community`
    * :func:`ResarchObject.delete_communities`
    * :func:`rohub.ros_list_main_entity`
    * :func:`rohub.ros_add_main_entity`
    * :func:`rohub.ros_delete_main_entity`
    * :func:`ResarchObject.add_main_entity`
    * :func:`ResarchObject.delete_main_entity`
    * :func:`admin.delete_custom_license`
    * :func:`rohub.ros_list_sketch`
    * :func:`rohub.ros_add_sketch`
    * :func:`ResarchObject.list_sketch`
    * :func:`ResarchObject.add_sketch`
- bugfix in :func:`ResarchObject.list_triples`; now the annotations will be automatically reloaded from the API to align python object with current API status, otherwise some new annotations could not appear until the object was reloaded